package cn.com.ctop.okr.controller;

import cn.com.ctop.okr.entity.OkrFocusInfo;
import cn.com.ctop.okr.service.IOkrFocusInfoService;
import cn.com.ctop.okr.service.OkrService;
import cn.com.ctop.okr.vo.Result;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;
import java.util.Map;

/**
 * 关注信息
 * @author jeecg-boot
 * @date   2020-09-05
 * @version V1.0
 */
@Slf4j
@RestController
@RequestMapping("/focusInfo")
public class OkrFocusInfoController {
	@Autowired
	private IOkrFocusInfoService okrFocusInfoService;
	@Autowired
	private OkrService okrService;
	@PostMapping("focus")
	public Map<String,Object>focus(@RequestBody JSONObject data){
		return okrFocusInfoService.focus(data);
	}

	@PostMapping("myFollow")
	public Map<String,Object>myFollow(@RequestBody JSONObject data){
		return okrService.getMyFollowList(data);
	}

	@PostMapping("myDepartment")
	public Map<String,Object>myDepartment(@RequestBody JSONObject data){
		return okrService.getMyDepartmentList(data);
	}

	/**
	  * 分页列表查询
	 * @param okrFocusInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */

	@GetMapping(value = "/list")
	public Result<IPage<OkrFocusInfo>> queryPageList(OkrFocusInfo okrFocusInfo,
													 @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
													 @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
													 HttpServletRequest req) {
		Result<IPage<OkrFocusInfo>> result = new Result<>();
		QueryWrapper<OkrFocusInfo> queryWrapper = new QueryWrapper<>();
		Page<OkrFocusInfo> page = new Page<>(pageNo, pageSize);
		IPage<OkrFocusInfo> pageList = okrFocusInfoService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	  *   添加
	 * @param okrFocusInfo
	 * @return
	 */
	@PostMapping(value = "/add")
	public Result<OkrFocusInfo> add(@RequestBody OkrFocusInfo okrFocusInfo) {
		Result<OkrFocusInfo> result = new Result<>();
		try {
			okrFocusInfoService.save(okrFocusInfo);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	  *  编辑
	 * @param okrFocusInfo
	 * @return
	 */
	@PutMapping(value = "/edit")
	public Result<OkrFocusInfo> edit(@RequestBody OkrFocusInfo okrFocusInfo) {
		Result<OkrFocusInfo> result = new Result<OkrFocusInfo>();
		OkrFocusInfo okrFocusInfoEntity = okrFocusInfoService.getById(okrFocusInfo.getId());
		if(okrFocusInfoEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = okrFocusInfoService.updateById(okrFocusInfo);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	  *   通过id删除
	 * @param id
	 * @return
	 */
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		try {
			okrFocusInfoService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	  *  批量删除
	 * @param ids
	 * @return
	 */
	@DeleteMapping(value = "/deleteBatch")
	public Result<OkrFocusInfo> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		Result<OkrFocusInfo> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.okrFocusInfoService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	  * 通过id查询
	 * @param id
	 * @return
	 */
	@GetMapping(value = "/queryById")
	public Result<OkrFocusInfo> queryById(@RequestParam(name="id",required=true) String id) {
		Result<OkrFocusInfo> result = new Result<>();
		OkrFocusInfo okrFocusInfo = okrFocusInfoService.getById(id);
		if(okrFocusInfo==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(okrFocusInfo);
			result.setSuccess(true);
		}
		return result;
	}
}
