package cn.com.ctop.okr.controller;

import cn.com.ctop.okr.entity.OkrObjectInfoRemind;
import cn.com.ctop.okr.service.IOkrObjectInfoRemindService;
import cn.com.ctop.okr.vo.Result;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;

 /**
 * okr 对象提醒信息
 * @author jeecg-boot
 * @date   2020-09-04
 * @version V1.0
 */
@Slf4j
@Api(tags="okr 对象提醒信息")
@RestController
@RequestMapping("/ctop/okrObjectInfoRemind")
public class OkrObjectInfoRemindController {
	@Autowired
	private IOkrObjectInfoRemindService okrObjectInfoRemindService;

	/**
	  * 分页列表查询
	 * @param okrObjectInfoRemind
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@GetMapping(value = "/list")
	public Result<IPage<OkrObjectInfoRemind>> queryPageList(OkrObjectInfoRemind okrObjectInfoRemind,
															@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
															@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
															HttpServletRequest req) {
		Result<IPage<OkrObjectInfoRemind>> result = new Result<>();
		QueryWrapper<OkrObjectInfoRemind> queryWrapper = new QueryWrapper<>();
		Page<OkrObjectInfoRemind> page = new Page<OkrObjectInfoRemind>(pageNo, pageSize);
		IPage<OkrObjectInfoRemind> pageList = okrObjectInfoRemindService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	  *   添加
	 * @param okrObjectInfoRemind
	 * @return
	 */
	@PostMapping(value = "/add")
	public Result<OkrObjectInfoRemind> add(@RequestBody OkrObjectInfoRemind okrObjectInfoRemind) {
		Result<OkrObjectInfoRemind> result = new Result<>();
		try {
			okrObjectInfoRemindService.save(okrObjectInfoRemind);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	  *  编辑
	 * @param okrObjectInfoRemind
	 * @return
	 */
	@PutMapping(value = "/edit")
	public Result<OkrObjectInfoRemind> edit(@RequestBody OkrObjectInfoRemind okrObjectInfoRemind) {
		Result<OkrObjectInfoRemind> result = new Result<OkrObjectInfoRemind>();
		OkrObjectInfoRemind okrObjectInfoRemindEntity = okrObjectInfoRemindService.getById(okrObjectInfoRemind.getId());
		if(okrObjectInfoRemindEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = okrObjectInfoRemindService.updateById(okrObjectInfoRemind);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	  *   通过id删除
	 * @param id
	 * @return
	 */
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		try {
			okrObjectInfoRemindService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	  *  批量删除
	 * @param ids
	 * @return
	 */
	@DeleteMapping(value = "/deleteBatch")
	public Result<OkrObjectInfoRemind> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		Result<OkrObjectInfoRemind> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.okrObjectInfoRemindService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	  * 通过id查询
	 * @param id
	 * @return
	 */
	@GetMapping(value = "/queryById")
	public Result<OkrObjectInfoRemind> queryById(@RequestParam(name="id",required=true) String id) {
		Result<OkrObjectInfoRemind> result = new Result<>();
		OkrObjectInfoRemind okrObjectInfoRemind = okrObjectInfoRemindService.getById(id);
		if(okrObjectInfoRemind==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(okrObjectInfoRemind);
			result.setSuccess(true);
		}
		return result;
	}
}
