package cn.com.ctop.okr.controller;

import cn.com.ctop.okr.entity.OkrTaskInfoRemind;
import cn.com.ctop.okr.service.IOkrTaskInfoRemindService;
import cn.com.ctop.okr.vo.Result;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;

 /**
 * okr 任务提醒信息
 * @author jeecg-boot
 * @date   2020-09-04
 * @version V1.0
 */
@Slf4j
@RestController
@RequestMapping("/ctop/okrTaskInfoRemind")
public class OkrTaskInfoRemindController {
	@Autowired
	private IOkrTaskInfoRemindService okrTaskInfoRemindService;

	/**
	  * 分页列表查询
	 * @param okrTaskInfoRemind
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@GetMapping(value = "/list")
	public Result<IPage<OkrTaskInfoRemind>> queryPageList(OkrTaskInfoRemind okrTaskInfoRemind,
														  @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
														  @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
														  HttpServletRequest req) {
		Result<IPage<OkrTaskInfoRemind>> result = new Result<>();
		QueryWrapper<OkrTaskInfoRemind> queryWrapper = new QueryWrapper<>();
		Page<OkrTaskInfoRemind> page = new Page<OkrTaskInfoRemind>(pageNo, pageSize);
		IPage<OkrTaskInfoRemind> pageList = okrTaskInfoRemindService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	  *   添加
	 * @param okrTaskInfoRemind
	 * @return
	 */
	@PostMapping(value = "/add")
	public Result<OkrTaskInfoRemind> add(@RequestBody OkrTaskInfoRemind okrTaskInfoRemind) {
		Result<OkrTaskInfoRemind> result = new Result<>();
		try {
			okrTaskInfoRemindService.save(okrTaskInfoRemind);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	  *  编辑
	 * @param okrTaskInfoRemind
	 * @return
	 */
	@PutMapping(value = "/edit")
	public Result<OkrTaskInfoRemind> edit(@RequestBody OkrTaskInfoRemind okrTaskInfoRemind) {
		Result<OkrTaskInfoRemind> result = new Result<OkrTaskInfoRemind>();
		OkrTaskInfoRemind okrTaskInfoRemindEntity = okrTaskInfoRemindService.getById(okrTaskInfoRemind.getId());
		if(okrTaskInfoRemindEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = okrTaskInfoRemindService.updateById(okrTaskInfoRemind);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	  *   通过id删除
	 * @param id
	 * @return
	 */
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		try {
			okrTaskInfoRemindService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	  *  批量删除
	 * @param ids
	 * @return
	 */
	@DeleteMapping(value = "/deleteBatch")
	public Result<OkrTaskInfoRemind> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		Result<OkrTaskInfoRemind> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.okrTaskInfoRemindService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	  * 通过id查询
	 * @param id
	 * @return
	 */
	@GetMapping(value = "/queryById")
	public Result<OkrTaskInfoRemind> queryById(@RequestParam(name="id",required=true) String id) {
		Result<OkrTaskInfoRemind> result = new Result<>();
		OkrTaskInfoRemind okrTaskInfoRemind = okrTaskInfoRemindService.getById(id);
		if(okrTaskInfoRemind==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(okrTaskInfoRemind);
			result.setSuccess(true);
		}
		return result;
	}
}
